==> twitter-client-0.0.2.tgz: package/tmp/test_twitter_client.js <==

var client = require('../lib/twitter-client');
var OAuth = require('oauth').OAuth;

var consumerKey = 'bQBa1ot7FjvsC3hhGaJwhg';
var consumerSecret = 'hUKOM8YP9FHfLGpRKsexLt7BoadLuv54v49jJmTM';
var accessToken = '212298323-8y6MiAQ0Y2aJN2FvnQuX0u4yfgLar3Dwrk0B5GPY';
var accessTokenSecret = 'HVjM0nsMbk57p666SR4NfSrO3Gb30GHjNgE7liH3sk';

var oauth = new OAuth('http://twitter.com/oauth/request_token',
                               'http://twitter.com/oauth/access_token',
                                consumerKey, consumerSecret,
                                '1.0', null, 'HMAC-SHA1');

var access = {token: accessToken, tokenSecret: accessTokenSecret};
bird = new client.Client(oauth, access);
//bird.on('onUserTimeline', function(err, data) {
//bird.on('onMentions', function(err, data) {
//bird.on('onDirectMessages', function(err, data) {
//bird.on('onNewDirectMessage', function(err, data) {
//bird.on('onUpdateStatus', function(err, data) {
//bird.on('onLists', function(err, data) {
//bird.on('onListTimeline', function(err, data) {
//bird.on('onListsMemberships', function(err, data) {
//bird.on('onFriends', function(err, data) {
bird.on('onFollowers', function(err, data) {
    if (err) {
        console.log('error');
    } else {
        console.log(data);
    }
});

//bird.userTimeline();
//bird.mentions();
//bird.directMessages();
//bird.newDirectMessage('vevisuke', 'param変更');
//bird.updateStatus('リファクタリングしても動く？');
//bird.lists();
//bird.listTimeline('pytwitman', 'testlist');
//bird.listTimeline();
//bird.listsMemberships();
//bird.friends();
bird.followers();

==> twitter-client-0.0.4.tgz: package/tmp/test_twitter_client.js <==

var client = require('../lib/twitter-client');
var OAuth = require('oauth').OAuth;

var consumerKey = 'bQBa1ot7FjvsC3hhGaJwhg';
var consumerSecret = 'hUKOM8YP9FHfLGpRKsexLt7BoadLuv54v49jJmTM';
var accessToken = '212298323-8y6MiAQ0Y2aJN2FvnQuX0u4yfgLar3Dwrk0B5GPY';
var accessTokenSecret = 'HVjM0nsMbk57p666SR4NfSrO3Gb30GHjNgE7liH3sk';

var oauth = new OAuth('http://twitter.com/oauth/request_token',
                               'http://twitter.com/oauth/access_token',
                                consumerKey, consumerSecret,
                                '1.0', null, 'HMAC-SHA1');

var access = {token: accessToken, tokenSecret: accessTokenSecret};
bird = new client.Client(oauth, access);
//bird.on('onUserTimeline', function(err, data) {
//bird.on('onMentions', function(err, data) {
//bird.on('onDirectMessages', function(err, data) {
//bird.on('onNewDirectMessage', function(err, data) {
//bird.on('onUpdateStatus', function(err, data) {
//bird.on('onLists', function(err, data) {
//bird.on('onListTimeline', function(err, data) {
bird.on('onListsMemberships', function(err, data) {
//bird.on('onFriends', function(err, data) {
//bird.on('onFollowers', function(err, data) {
    if (err) {
        console.log('error');
    } else {
        console.log(data);
    }
});

//bird.userTimeline();
//bird.mentions();
//bird.directMessages();
//bird.newDirectMessage('vevisuke', 'param変更');
//bird.updateStatus('リファクタリングしても動く？');
//bird.lists();
//bird.listTimeline('pytwitman', 'testlist');
//bird.listTimeline();
//bird.listsMemberships();
bird.listsMemberships('vevisuke');
bird.listsMemberships('pytwitman');
//bird.friends();
//bird.followers();
